import * as ethers from 'ethers';
import { providers, BigNumber, Signer, BigNumberish } from 'ethers';

declare type GetMarketInfoOptions = {
    provider: providers.Provider;
    contractAddress: string;
    tokenId: number;
    referrer?: string;
};
declare type Maybe<T> = T | undefined;
declare type Value = {
    value: BigNumber;
    formatted: string;
};
declare type Auction = {
    isAuctionLive: boolean;
    highestBidderAddress: Maybe<string>;
    endsAt: Maybe<number>;
    amount: Value;
    id: number;
    link: string;
};
declare type Offer = {
    amount: Value;
    offererAddress: string;
    offerExpiresAt: number;
    link: string;
};
declare type BuyNow = {
    amount: Value;
    link: string;
};
declare type GetMarketInfoResult = {
    ownerAddress: string;
    isInEscrow: boolean;
    auction: Maybe<Auction>;
    buyNow: Maybe<BuyNow>;
    offer: Maybe<Offer>;
};
declare function getMarketInfo(options: GetMarketInfoOptions): Promise<GetMarketInfoResult>;

declare type SendOfferOptions = {
    signer: Signer;
    contractAddress: string;
    tokenId: number;
    amount: string;
    referrer?: string;
    gasMargin?: number;
};
declare function sendOffer(options: SendOfferOptions): Promise<ethers.ContractTransaction>;

declare type SendBuyNowOptions = {
    signer: Signer;
    contractAddress: string;
    tokenId: number;
    referrer?: string;
    gasMargin?: number;
};
declare function sendBuyNow(options: SendBuyNowOptions): Promise<ethers.ContractTransaction>;

declare type SendBidOptions = {
    signer: Signer;
    contractAddress: string;
    tokenId: number;
    amount: string;
    referrer?: string;
    gasMargin?: number;
};
declare function sendBid(options: SendBidOptions): Promise<ethers.ContractTransaction>;

declare type GetLastSoldPriceOptions = {
    provider: providers.Provider;
    contractAddress: string;
    tokenId: number;
};
declare type GetLastSoldPriceResult = {
    value: BigNumber;
    formatted: string;
};
declare function getLastSoldPrice(options: GetLastSoldPriceOptions): Promise<GetLastSoldPriceResult>;

declare type CalculatePercentageIncreaseOptions = {
    value: BigNumber;
    margin?: BigNumberish;
};
declare function calculatePercentageIncrease(options: CalculatePercentageIncreaseOptions): BigNumber;

export { GetLastSoldPriceOptions, GetLastSoldPriceResult, GetMarketInfoOptions, GetMarketInfoResult, SendBidOptions, SendBuyNowOptions, SendOfferOptions, calculatePercentageIncrease, getLastSoldPrice, getMarketInfo, sendBid, sendBuyNow, sendOffer };
